# NyanPy
The cutest little assortment of nifty Python tools.

## Overview
MeowMeow is a collection of nifty Python tools designed to simplify file and directory operations. 

## Installation
You can install the project using pip. Simply run:

```bash
pip install nyanpy
```

## Usage
To use the tools provided in this package, you can import them in your Python scripts:

```python
from nyanpy.filetools import dir_to_file_list, create_directory_tree
```

## Contributing
Contributions are welcome! Please open an issue or submit a pull request for any improvements or bug fixes.

## License
This project is licensed under the MIT License. See the LICENSE file for details.